/**
 * Get used package manager according to the unique lock file of each package manager.
 *
 * - yarn.lock => yarn
 * - package-lock.json => npm
 * - pnpm-lock.yaml => pnpm
 * - _ => unknown
 */
export declare function getPackageManager(dir: string): PackageManager;

/**
 * Get project paths.
 * Directory containing `./package.json` will be considered projects.
 *
 * If current path is under a subproject (for example, in a workspace),
 * the result will be like
 * `[currentProjectDirectory, parentProjectDirectory, ..., rootProjectDirectory]`.
 *
 * If no project directory is found, returns [cwd].
 */
export declare function getProjectPath(): string[];

export declare type Host = 'vite' | 'rollup' | 'webpack' | 'test';

export declare function isArray(v: unknown): v is Array<any>;

export declare function isAsyncFunction(fn: Function): boolean;

export declare function isError(v: unknown): v is Error;

export declare function isFunction(o: unknown): o is Function;

export declare function isGeneratorFunction(fn: Function): fn is GeneratorFunction;

export declare function isPromise(v: unknown): v is Promise<unknown>;

export declare function isString(v: unknown): v is string;

export declare const NO_OP: () => void;

export declare function normalizePath(path: string): string;

export declare type PackageManager = 'yarn' | 'npm' | 'pnpm' | 'test' | 'unknown';

export declare type Thenable<T> = T | Promise<T>;

export declare type TransformResult = string | null | undefined | {
    code: string;
    map?: string | null | {
        mappings: '';
    };
};

export declare function validateFnName(name: string): boolean;

/**
 * Global version number.
 *
 * When components are compatible, the version numbers must be equal;
 * when the version numbers are equal, the components must be compatible.
 *
 * Runtime should check the version of providers and macros.
 *
 * Provider doesn't need to check the version of macro because it is
 * only the wrapper of the macro,
 * which has nothing to do with the implementation and shape of macros,
 * and this independence should be guaranteed.
 */
export declare const VERSION = "1";

export { }
