// src/utils.ts
import { existsSync } from "fs";
import { posix, resolve, sep, win32 } from "path";
function validateFnName(name) {
  return /^[_$a-zA-Z\xA0-\uFFFF][_$a-zA-Z0-9\xA0-\uFFFF]*$/.test(name);
}
function normalizePath(path) {
  return path.split(win32.sep).join(posix.sep);
}
function isString(v) {
  return typeof v === "string";
}
function isPromise(v) {
  return Promise.resolve(v) === v;
}
function isError(v) {
  return v instanceof Error;
}
function isArray(v) {
  return Array.isArray(v);
}
function isFunction(o) {
  return o instanceof Function;
}
function isAsyncFunction(fn) {
  return fn.constructor.name.includes("Async");
}
function isGeneratorFunction(fn) {
  return fn.constructor.name.includes("Generator");
}
function getProjectPath() {
  const cwd = process.cwd();
  const paths = cwd.split(sep);
  const result = [];
  for (let i = paths.length; i > 0; i--) {
    const path = paths.slice(0, i).join(sep);
    if (existsSync([path, "package.json"].join(sep)))
      result.push(path);
  }
  return result.length ? result : [cwd];
}
function getPackageManager(dir) {
  if (existsSync(resolve(dir, "yarn.lock")))
    return "yarn";
  if (existsSync(resolve(dir, "package-lock.json")))
    return "npm";
  if (existsSync(resolve(dir, "pnpm-lock.yaml")))
    return "pnpm";
  return "unknown";
}
var NO_OP = () => {
};

// src/version.ts
var VERSION = "1";
export {
  NO_OP,
  VERSION,
  getPackageManager,
  getProjectPath,
  isArray,
  isAsyncFunction,
  isError,
  isFunction,
  isGeneratorFunction,
  isPromise,
  isString,
  normalizePath,
  validateFnName
};
